AdbiDriver-class: Class AdbiDriver (and methods)

AdbiDriver-classR Documentation

Class AdbiDriver (and methods)

Description

AdbiDriver objects are created by adbi(), and used to select the correct method in DBI::dbConnect(). They are a superclass of the DBI::DBIDriver class, and used purely for dispatch. The "Usage" section lists the class methods overridden by adbi.

Usage

## S4 method for signature 'AdbiDriver'
dbDataType(dbObj, obj, ...)

## S4 method for signature 'AdbiDriver'
dbGetInfo(dbObj, ...)

## S4 method for signature 'AdbiDriver'
dbIsValid(dbObj, ...)

## S4 method for signature 'AdbiDriver'
show(object)

Arguments

dbObj

A object inheriting from DBI::DBIDriver or DBI::DBIConnection

obj

An R object whose SQL type we want to determine.

...

Other arguments passed on to methods.

object

Any R object

Value

The DBI methods return what their generics specify, as documented on the generic's help page, for example DBI::dbGetInfo(). The show() method is called for its side effect of printing a summary.


adbi documentation built on Sept. 25, 2026, 5:08 p.m.